# coding: utf-8
from io import BytesIO
from maxipago.utils import etree
from maxipago.resources.base import Resource
from maxipago.exceptions import PaymentException


class CancelResource(Resource):

    def process(self):
    
        tree = etree.parse(BytesIO(self.data))
        print(etree.tostring(tree, pretty_print=True, encoding='unicode'))
        error_code = tree.find('errorCode')
        if error_code is not None and error_code.text != '0':
            error_message = tree.find('errorMsg').text
            raise PaymentException(message=error_message)

        fields = [
            ('errorCode', 'processor_code'),
            ('errorMessage', 'error_message'),
            ('time', 'transaction_timestamp'),
            ('result', 'processor_message')
        ]

        for f_name, f_translated in fields:
            field = tree.find(f_name)
            print(field)
            if field:
                setattr(self, f_translated, field.text)



class EditResource(Resource):

    def process(self):
    
        tree = etree.parse(BytesIO(self.data))
        error_code = tree.find('errorCode')

        fields = [
            ('errorCode', 'processor_code'),
            ('errorMessage', 'error_message'),
            ('time', 'transaction_timestamp'),
            ('result', 'processor_message')
        ]

        for f_name, f_translated in fields:
            field = tree.find(f_name)
            if field is not None:
                setattr(self, f_translated, field.text)



# coding: utf-8
from .base import ManagerApi
from maxipago.requesters.card import CardRequester
from maxipago.resources.card import CardAddResource, CardDeleteResource


class CardManager(ManagerApi):

    def add(self, **kwargs):
        fields = (
            ('customer_id', {'translated_name': 'customerId'}),
            ('number', {'translated_name': 'creditCardNumber'}),
            ('expiration_month', {'translated_name': 'expirationMonth'}),
            ('expiration_year', {'translated_name': 'expirationYear'}),
            ('billing_name', {'translated_name': 'billingName'}),
            ('billing_address1', {'translated_name': 'billingAddress1'}),
            ('billing_address2', {'translated_name': 'billingAddress2', 'required': False}),
            ('billing_city', {'translated_name': 'billingCity'}),
            ('billing_state', {'translated_name': 'billingState'}),
            ('billing_zip', {'translated_name': 'billingZip'}),
            ('billing_country', {'translated_name': 'billingCountry'}),
            ('billing_phone', {'translated_name': 'billingPhone'}),
            ('billing_email', {'translated_name': 'billingEmail'}),
            ('onfile_end_date', {'translated_name': 'onFileEndDate', 'required': False}),
            ('onfile_permissions', {'translated_name': 'onFilePermissions', 'required': False}),
            ('onfile_comment', {'translated_name': 'onFileComment', 'required': False}),
            ('onfile_max_charge_amount', {'translated_name': 'onFileMaxChargeAmount', 'required': False}),
        )
        requester = CardRequester(fields, kwargs)
        return self.send(command='add-card-onfile', requester=requester, resource=CardAddResource)

    def delete(self, **kwargs):
        fields = (
            ('customer_id', {'translated_name': 'customerId'}),
            ('token', {}),
        )
        requester = CardRequester(fields, kwargs)
        return self.send(command='delete-card-onfile', requester=requester, resource=CardDeleteResource)



# coding: utf-8
import re
import os
from setuptools import setup, find_packages
from codecs import open



def read_file(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


def get_version():
    meta_filedata = read_file('maxipago/__init__.py')
    re_version = re.compile(r'VERSION\s*=\s*\((.*?)\)')
    group = re_version.search(meta_filedata).group(1)
    version = filter(None, map(lambda s: s.strip(), group.split(',')))
    return '.'.join(version)


setup(
    name='maxipago-sdk',
    version=get_version(),
    author='Stored',
    author_email='contato@stored.com.br',
    description='SDK python',
    license='MIT',
    keywords='',
    url='https://github.com/tsneu/sdk-python',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    long_description=read_file('README.md'),
    classifiers=[
        "Topic :: Utilities",
    ],
    install_requires=[
        'requests==2.20.0',
        'lxml==4.1.1',
        'pyOpenSSL==18.0.0'
    ],
)



# coding: utf-8
from maxipago.managers.base import ManagerTransaction, ManagerApi
from maxipago.requesters.payment import PaymentRecurringRequester
from maxipago.resources.payment import PaymentResource
from maxipago.resources.recurring import CancelResource, EditResource

class PaymentRecurringManager(ManagerTransaction):

    def add(self, **kwargs):
        fields = (
            ('processor_id', {'translated_name': 'processorID'}),
            ('reference_num', {'translated_name': 'referenceNum'}),
            ('ip_address', {'translated_name': 'ipAddress', 'required': False}),

            ('card_number', {'translated_name': 'transactionDetail/payType/creditCard/number'}),
            ('card_expiration_month', {'translated_name': 'transactionDetail/payType/creditCard/expMonth'}),
            ('card_expiration_year', {'translated_name': 'transactionDetail/payType/creditCard/expYear'}),
            ('card_cvv', {'translated_name': 'transactionDetail/payType/creditCard/cvvNumber', 'required': False}),

            ('charge_total', {'translated_name': 'payment/chargeTotal'}),
            ('currency_code', {'translated_name': 'payment/currencyCode', 'required': True}),

            ('recurring_action', {'translated_name': 'recurring/action', 'default': 'new'}),
            ('recurring_start', {'translated_name': 'recurring/startDate', 'required': False}),
            ('recurring_last', {'translated_name': 'recurring/lastDate', 'required': False}),
            ('recurring_frequency', {'translated_name': 'recurring/frequency'}),
            ('recurring_period', {'translated_name': 'recurring/period'}),
            ('recurring_first_amount', {'translated_name': 'recurring/firstAmount', 'required': False}),
            ('recurring_last_amount', {'translated_name': 'recurring/lastAmount', 'required': False}),
            ('recurring_installments', {'translated_name': 'recurring/installments'}),
            ('recurring_failure_threshold', {'translated_name': 'recurring/failureThreshold', 'required': False}),
        )
        
        requester = PaymentRecurringRequester(fields, kwargs)       
        return self.send(command='recurringPayment', requester=requester, resource=PaymentResource)


    def delete(self, **kwargs):
        fields = (
            ('order_id', {'translated_name': 'orderID'}),
        )

        requester = PaymentRecurringRequester(fields, kwargs)
        
        manager = ManagerApi(maxid=self.maxid, api_key=self.api_key, api_version=self.api_version, sandbox=self.sandbox)
        return manager.send(command='cancel-recurring', requester=requester, resource=CancelResource)


class PaymentRecurringManagerApi(ManagerApi):

    def edit(self, **kwargs):
        
        fields = (
            ('order_id', {'translated_name': 'orderID'}),

            ('card_number', {'translated_name': 'paymentInfo/cardInfo/creditCardNumber', 'required': False}),
            ('card_expiration_month', {'translated_name': 'paymentInfo/cardInfo/expirationMonth', 'required': False}),
            ('card_expiration_year', {'translated_name': 'paymentInfo/cardInfo/expirationYear', 'required': False}),
            ('card_soft_description', {'translated_name': 'paymentInfo/cardInfo/softDescriptor', 'required': False}),

            ('charge_total', {'translated_name': 'paymentInfo/chargeTotal'}),

            ('processor_id', {'translated_name': 'recurring/processorID', 'Required': False}),
            ('recurring_action', {'translated_name': 'recurring/action', 'default': 'enabled', 'required': True}),
            ('recurring_installments', {'translated_name': 'recurring/installments'}),
            ('recurring_next_date', {'translated_name': 'recurring/nextFireDate', 'required': False}),
            ('recurring_day', {'translated_name': 'recurring/fireDay', 'required': False}),
            ('recurring_period', {'translated_name': 'recurring/period', 'required': False}),
            ('recurring_last_date', {'translated_name': 'recurring/lastDate', 'required': False}),
            ('recurring_last_amount', {'translated_name': 'recurring/lastAmount', 'required': False}),
            
            ('billing_name', {'translated_name': 'billingInfo/name', 'required': False}),
            ('billing_address', {'translated_name': 'billingInfo/address1', 'required': False}),
            ('billing_address2', {'translated_name': 'billingInfo/address2', 'required': False}),
            ('billing_city', {'translated_name': 'billingInfo/city', 'required': False}),
            ('billing_postalcode', {'translated_name': 'billingInfo/zip', 'required': False}),
            ('billing_country', {'translated_name': 'billingInfo/country', 'required': False}),
            ('billing_email', {'translated_name': 'billingInfo/email', 'required': False}),
            ('billing_phone', {'translated_name': 'billingInfo/phone', 'required': False}),

            ('shipping_name', {'translated_name': 'shippingInfo/name', 'required': False}),
            ('shipping_address', {'translated_name': 'shippingInfo/address1', 'required': False}),
            ('shipping_address2', {'translated_name': 'shippingInfo/address2', 'required': False}),
            ('shipping_city', {'translated_name': 'shippingInfo/city', 'required': False}),
            ('shipping_postalcode', {'translated_name': 'shippingInfo/zip', 'required': False}),
            ('shipping_country', {'translated_name': 'shippingInfo/country', 'required': False}),
            ('shipping_email', {'translated_name': 'shippingInfo/email', 'required': False}),
            ('shipping_phone', {'translated_name': 'shippingInfo/phone', 'required': False}),
        )
        
        requester = PaymentRecurringRequester(fields, kwargs)
        return self.send(command='modify-recurring', requester=requester, resource=EditResource)
